# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPrivateDatabaseResult',
    'AwaitableGetPrivateDatabaseResult',
    'get_private_database',
    'get_private_database_output',
]

@pulumi.output_type
class GetPrivateDatabaseResult:
    """
    A collection of values returned by getPrivateDatabase.
    """
    def __init__(__self__, cpu=None, datacenter=None, display_name=None, hostname=None, hostname_ftp=None, id=None, infrastructure=None, offer=None, port=None, port_ftp=None, quota_size=None, quota_used=None, ram=None, server=None, service_name=None, state=None, type=None, urn=None, version=None, version_label=None, version_number=None):
        if cpu and not isinstance(cpu, int):
            raise TypeError("Expected argument 'cpu' to be a int")
        pulumi.set(__self__, "cpu", cpu)
        if datacenter and not isinstance(datacenter, str):
            raise TypeError("Expected argument 'datacenter' to be a str")
        pulumi.set(__self__, "datacenter", datacenter)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if hostname_ftp and not isinstance(hostname_ftp, str):
            raise TypeError("Expected argument 'hostname_ftp' to be a str")
        pulumi.set(__self__, "hostname_ftp", hostname_ftp)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if infrastructure and not isinstance(infrastructure, str):
            raise TypeError("Expected argument 'infrastructure' to be a str")
        pulumi.set(__self__, "infrastructure", infrastructure)
        if offer and not isinstance(offer, str):
            raise TypeError("Expected argument 'offer' to be a str")
        pulumi.set(__self__, "offer", offer)
        if port and not isinstance(port, int):
            raise TypeError("Expected argument 'port' to be a int")
        pulumi.set(__self__, "port", port)
        if port_ftp and not isinstance(port_ftp, int):
            raise TypeError("Expected argument 'port_ftp' to be a int")
        pulumi.set(__self__, "port_ftp", port_ftp)
        if quota_size and not isinstance(quota_size, int):
            raise TypeError("Expected argument 'quota_size' to be a int")
        pulumi.set(__self__, "quota_size", quota_size)
        if quota_used and not isinstance(quota_used, int):
            raise TypeError("Expected argument 'quota_used' to be a int")
        pulumi.set(__self__, "quota_used", quota_used)
        if ram and not isinstance(ram, int):
            raise TypeError("Expected argument 'ram' to be a int")
        pulumi.set(__self__, "ram", ram)
        if server and not isinstance(server, str):
            raise TypeError("Expected argument 'server' to be a str")
        pulumi.set(__self__, "server", server)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if urn and not isinstance(urn, str):
            raise TypeError("Expected argument 'urn' to be a str")
        pulumi.set(__self__, "urn", urn)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if version_label and not isinstance(version_label, str):
            raise TypeError("Expected argument 'version_label' to be a str")
        pulumi.set(__self__, "version_label", version_label)
        if version_number and not isinstance(version_number, float):
            raise TypeError("Expected argument 'version_number' to be a float")
        pulumi.set(__self__, "version_number", version_number)

    @property
    @pulumi.getter
    def cpu(self) -> builtins.int:
        """
        Number of CPU on your private database
        """
        return pulumi.get(self, "cpu")

    @property
    @pulumi.getter
    def datacenter(self) -> builtins.str:
        """
        Datacenter where this private database is located
        """
        return pulumi.get(self, "datacenter")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Name displayed in customer panel for your private database
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def hostname(self) -> builtins.str:
        """
        Private database hostname
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter(name="hostnameFtp")
    def hostname_ftp(self) -> builtins.str:
        """
        Private database FTP hostname
        """
        return pulumi.get(self, "hostname_ftp")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def infrastructure(self) -> builtins.str:
        """
        Infrastructure where service was stored
        """
        return pulumi.get(self, "infrastructure")

    @property
    @pulumi.getter
    def offer(self) -> builtins.str:
        """
        Type of the private database offer
        """
        return pulumi.get(self, "offer")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        Private database service port
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="portFtp")
    def port_ftp(self) -> builtins.int:
        """
        Private database FTP port
        """
        return pulumi.get(self, "port_ftp")

    @property
    @pulumi.getter(name="quotaSize")
    def quota_size(self) -> builtins.int:
        """
        Space allowed (in MB) on your private database
        """
        return pulumi.get(self, "quota_size")

    @property
    @pulumi.getter(name="quotaUsed")
    def quota_used(self) -> builtins.int:
        """
        Sapce used (in MB) on your private database
        """
        return pulumi.get(self, "quota_used")

    @property
    @pulumi.getter
    def ram(self) -> builtins.int:
        """
        Amount of ram (in MB) on your private database
        """
        return pulumi.get(self, "ram")

    @property
    @pulumi.getter
    def server(self) -> builtins.str:
        """
        Private database server name
        """
        return pulumi.get(self, "server")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def state(self) -> builtins.str:
        """
        Private database state
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        URN of the private database
        """
        return pulumi.get(self, "urn")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        Private database available versions
        """
        return pulumi.get(self, "version")

    @property
    @pulumi.getter(name="versionLabel")
    def version_label(self) -> builtins.str:
        """
        Private database version label
        """
        return pulumi.get(self, "version_label")

    @property
    @pulumi.getter(name="versionNumber")
    def version_number(self) -> builtins.float:
        """
        Private database version number
        """
        return pulumi.get(self, "version_number")


class AwaitableGetPrivateDatabaseResult(GetPrivateDatabaseResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrivateDatabaseResult(
            cpu=self.cpu,
            datacenter=self.datacenter,
            display_name=self.display_name,
            hostname=self.hostname,
            hostname_ftp=self.hostname_ftp,
            id=self.id,
            infrastructure=self.infrastructure,
            offer=self.offer,
            port=self.port,
            port_ftp=self.port_ftp,
            quota_size=self.quota_size,
            quota_used=self.quota_used,
            ram=self.ram,
            server=self.server,
            service_name=self.service_name,
            state=self.state,
            type=self.type,
            urn=self.urn,
            version=self.version,
            version_label=self.version_label,
            version_number=self.version_number)


def get_private_database(service_name: Optional[builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrivateDatabaseResult:
    """
    Use this data source to retrieve information about an hosting database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    database = ovh.Hosting.get_private_database(service_name="XXXXXX")
    ```


    :param builtins.str service_name: The internal name of your private database
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Hosting/getPrivateDatabase:getPrivateDatabase', __args__, opts=opts, typ=GetPrivateDatabaseResult).value

    return AwaitableGetPrivateDatabaseResult(
        cpu=pulumi.get(__ret__, 'cpu'),
        datacenter=pulumi.get(__ret__, 'datacenter'),
        display_name=pulumi.get(__ret__, 'display_name'),
        hostname=pulumi.get(__ret__, 'hostname'),
        hostname_ftp=pulumi.get(__ret__, 'hostname_ftp'),
        id=pulumi.get(__ret__, 'id'),
        infrastructure=pulumi.get(__ret__, 'infrastructure'),
        offer=pulumi.get(__ret__, 'offer'),
        port=pulumi.get(__ret__, 'port'),
        port_ftp=pulumi.get(__ret__, 'port_ftp'),
        quota_size=pulumi.get(__ret__, 'quota_size'),
        quota_used=pulumi.get(__ret__, 'quota_used'),
        ram=pulumi.get(__ret__, 'ram'),
        server=pulumi.get(__ret__, 'server'),
        service_name=pulumi.get(__ret__, 'service_name'),
        state=pulumi.get(__ret__, 'state'),
        type=pulumi.get(__ret__, 'type'),
        urn=pulumi.get(__ret__, 'urn'),
        version=pulumi.get(__ret__, 'version'),
        version_label=pulumi.get(__ret__, 'version_label'),
        version_number=pulumi.get(__ret__, 'version_number'))
def get_private_database_output(service_name: Optional[pulumi.Input[builtins.str]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPrivateDatabaseResult]:
    """
    Use this data source to retrieve information about an hosting database.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    database = ovh.Hosting.get_private_database(service_name="XXXXXX")
    ```


    :param builtins.str service_name: The internal name of your private database
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Hosting/getPrivateDatabase:getPrivateDatabase', __args__, opts=opts, typ=GetPrivateDatabaseResult)
    return __ret__.apply(lambda __response__: GetPrivateDatabaseResult(
        cpu=pulumi.get(__response__, 'cpu'),
        datacenter=pulumi.get(__response__, 'datacenter'),
        display_name=pulumi.get(__response__, 'display_name'),
        hostname=pulumi.get(__response__, 'hostname'),
        hostname_ftp=pulumi.get(__response__, 'hostname_ftp'),
        id=pulumi.get(__response__, 'id'),
        infrastructure=pulumi.get(__response__, 'infrastructure'),
        offer=pulumi.get(__response__, 'offer'),
        port=pulumi.get(__response__, 'port'),
        port_ftp=pulumi.get(__response__, 'port_ftp'),
        quota_size=pulumi.get(__response__, 'quota_size'),
        quota_used=pulumi.get(__response__, 'quota_used'),
        ram=pulumi.get(__response__, 'ram'),
        server=pulumi.get(__response__, 'server'),
        service_name=pulumi.get(__response__, 'service_name'),
        state=pulumi.get(__response__, 'state'),
        type=pulumi.get(__response__, 'type'),
        urn=pulumi.get(__response__, 'urn'),
        version=pulumi.get(__response__, 'version'),
        version_label=pulumi.get(__response__, 'version_label'),
        version_number=pulumi.get(__response__, 'version_number')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ServerCustomizationsArgs',
    'ServerCustomizationsArgsDict',
    'ServerIamArgs',
    'ServerIamArgsDict',
    'ServerNetworkingInterfaceArgs',
    'ServerNetworkingInterfaceArgsDict',
    'ServerOrderArgs',
    'ServerOrderArgsDict',
    'ServerOrderDetailArgs',
    'ServerOrderDetailArgsDict',
    'ServerPlanArgs',
    'ServerPlanArgsDict',
    'ServerPlanConfigurationArgs',
    'ServerPlanConfigurationArgsDict',
    'ServerPlanOptionArgs',
    'ServerPlanOptionArgsDict',
    'ServerPlanOptionConfigurationArgs',
    'ServerPlanOptionConfigurationArgsDict',
    'ServerReinstallTaskCustomizationsArgs',
    'ServerReinstallTaskCustomizationsArgsDict',
    'ServerReinstallTaskStorageArgs',
    'ServerReinstallTaskStorageArgsDict',
    'ServerReinstallTaskStorageHardwareRaidArgs',
    'ServerReinstallTaskStorageHardwareRaidArgsDict',
    'ServerReinstallTaskStoragePartitioningArgs',
    'ServerReinstallTaskStoragePartitioningArgsDict',
    'ServerReinstallTaskStoragePartitioningLayoutArgs',
    'ServerReinstallTaskStoragePartitioningLayoutArgsDict',
    'ServerReinstallTaskStoragePartitioningLayoutExtraArgs',
    'ServerReinstallTaskStoragePartitioningLayoutExtraArgsDict',
    'ServerReinstallTaskStoragePartitioningLayoutExtraLvArgs',
    'ServerReinstallTaskStoragePartitioningLayoutExtraLvArgsDict',
    'ServerReinstallTaskStoragePartitioningLayoutExtraZpArgs',
    'ServerReinstallTaskStoragePartitioningLayoutExtraZpArgsDict',
    'ServerStorageArgs',
    'ServerStorageArgsDict',
    'ServerStorageHardwareRaidArgs',
    'ServerStorageHardwareRaidArgsDict',
    'ServerStoragePartitioningArgs',
    'ServerStoragePartitioningArgsDict',
    'ServerStoragePartitioningLayoutArgs',
    'ServerStoragePartitioningLayoutArgsDict',
    'ServerStoragePartitioningLayoutExtrasArgs',
    'ServerStoragePartitioningLayoutExtrasArgsDict',
    'ServerStoragePartitioningLayoutExtrasLvArgs',
    'ServerStoragePartitioningLayoutExtrasLvArgsDict',
    'ServerStoragePartitioningLayoutExtrasZpArgs',
    'ServerStoragePartitioningLayoutExtrasZpArgsDict',
]

MYPY = False

if not MYPY:
    class ServerCustomizationsArgsDict(TypedDict):
        config_drive_user_data: NotRequired[pulumi.Input[builtins.str]]
        """
        Config Drive UserData
        """
        efi_bootloader_path: NotRequired[pulumi.Input[builtins.str]]
        """
        Path of the EFI bootloader
        """
        hostname: NotRequired[pulumi.Input[builtins.str]]
        """
        Custom hostname
        """
        http_headers: NotRequired[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]
        """
        Image HTTP Headers
        """
        image_check_sum: NotRequired[pulumi.Input[builtins.str]]
        """
        Image checksum
        """
        image_check_sum_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Checksum type
        """
        image_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Image Type
        """
        image_url: NotRequired[pulumi.Input[builtins.str]]
        """
        Image URL
        """
        language: NotRequired[pulumi.Input[builtins.str]]
        """
        Display Language
        """
        post_installation_script: NotRequired[pulumi.Input[builtins.str]]
        """
        Post-Installation Script
        """
        post_installation_script_extension: NotRequired[pulumi.Input[builtins.str]]
        """
        Post-Installation Script File Extension
        """
        ssh_key: NotRequired[pulumi.Input[builtins.str]]
        """
        SSH Public Key
        """
elif False:
    ServerCustomizationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerCustomizationsArgs:
    def __init__(__self__, *,
                 config_drive_user_data: Optional[pulumi.Input[builtins.str]] = None,
                 efi_bootloader_path: Optional[pulumi.Input[builtins.str]] = None,
                 hostname: Optional[pulumi.Input[builtins.str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 image_check_sum: Optional[pulumi.Input[builtins.str]] = None,
                 image_check_sum_type: Optional[pulumi.Input[builtins.str]] = None,
                 image_type: Optional[pulumi.Input[builtins.str]] = None,
                 image_url: Optional[pulumi.Input[builtins.str]] = None,
                 language: Optional[pulumi.Input[builtins.str]] = None,
                 post_installation_script: Optional[pulumi.Input[builtins.str]] = None,
                 post_installation_script_extension: Optional[pulumi.Input[builtins.str]] = None,
                 ssh_key: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] config_drive_user_data: Config Drive UserData
        :param pulumi.Input[builtins.str] efi_bootloader_path: Path of the EFI bootloader
        :param pulumi.Input[builtins.str] hostname: Custom hostname
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] http_headers: Image HTTP Headers
        :param pulumi.Input[builtins.str] image_check_sum: Image checksum
        :param pulumi.Input[builtins.str] image_check_sum_type: Checksum type
        :param pulumi.Input[builtins.str] image_type: Image Type
        :param pulumi.Input[builtins.str] image_url: Image URL
        :param pulumi.Input[builtins.str] language: Display Language
        :param pulumi.Input[builtins.str] post_installation_script: Post-Installation Script
        :param pulumi.Input[builtins.str] post_installation_script_extension: Post-Installation Script File Extension
        :param pulumi.Input[builtins.str] ssh_key: SSH Public Key
        """
        if config_drive_user_data is not None:
            pulumi.set(__self__, "config_drive_user_data", config_drive_user_data)
        if efi_bootloader_path is not None:
            pulumi.set(__self__, "efi_bootloader_path", efi_bootloader_path)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if http_headers is not None:
            pulumi.set(__self__, "http_headers", http_headers)
        if image_check_sum is not None:
            pulumi.set(__self__, "image_check_sum", image_check_sum)
        if image_check_sum_type is not None:
            pulumi.set(__self__, "image_check_sum_type", image_check_sum_type)
        if image_type is not None:
            pulumi.set(__self__, "image_type", image_type)
        if image_url is not None:
            pulumi.set(__self__, "image_url", image_url)
        if language is not None:
            pulumi.set(__self__, "language", language)
        if post_installation_script is not None:
            pulumi.set(__self__, "post_installation_script", post_installation_script)
        if post_installation_script_extension is not None:
            pulumi.set(__self__, "post_installation_script_extension", post_installation_script_extension)
        if ssh_key is not None:
            pulumi.set(__self__, "ssh_key", ssh_key)

    @property
    @pulumi.getter(name="configDriveUserData")
    def config_drive_user_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Config Drive UserData
        """
        return pulumi.get(self, "config_drive_user_data")

    @config_drive_user_data.setter
    def config_drive_user_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_drive_user_data", value)

    @property
    @pulumi.getter(name="efiBootloaderPath")
    def efi_bootloader_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Path of the EFI bootloader
        """
        return pulumi.get(self, "efi_bootloader_path")

    @efi_bootloader_path.setter
    def efi_bootloader_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "efi_bootloader_path", value)

    @property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom hostname
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter(name="httpHeaders")
    def http_headers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Image HTTP Headers
        """
        return pulumi.get(self, "http_headers")

    @http_headers.setter
    def http_headers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "http_headers", value)

    @property
    @pulumi.getter(name="imageCheckSum")
    def image_check_sum(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image checksum
        """
        return pulumi.get(self, "image_check_sum")

    @image_check_sum.setter
    def image_check_sum(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_check_sum", value)

    @property
    @pulumi.getter(name="imageCheckSumType")
    def image_check_sum_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Checksum type
        """
        return pulumi.get(self, "image_check_sum_type")

    @image_check_sum_type.setter
    def image_check_sum_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_check_sum_type", value)

    @property
    @pulumi.getter(name="imageType")
    def image_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image Type
        """
        return pulumi.get(self, "image_type")

    @image_type.setter
    def image_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_type", value)

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image URL
        """
        return pulumi.get(self, "image_url")

    @image_url.setter
    def image_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_url", value)

    @property
    @pulumi.getter
    def language(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Display Language
        """
        return pulumi.get(self, "language")

    @language.setter
    def language(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "language", value)

    @property
    @pulumi.getter(name="postInstallationScript")
    def post_installation_script(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Post-Installation Script
        """
        return pulumi.get(self, "post_installation_script")

    @post_installation_script.setter
    def post_installation_script(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "post_installation_script", value)

    @property
    @pulumi.getter(name="postInstallationScriptExtension")
    def post_installation_script_extension(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Post-Installation Script File Extension
        """
        return pulumi.get(self, "post_installation_script_extension")

    @post_installation_script_extension.setter
    def post_installation_script_extension(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "post_installation_script_extension", value)

    @property
    @pulumi.getter(name="sshKey")
    def ssh_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SSH Public Key
        """
        return pulumi.get(self, "ssh_key")

    @ssh_key.setter
    def ssh_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssh_key", value)


if not MYPY:
    class ServerIamArgsDict(TypedDict):
        display_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Resource display name
        """
        id: NotRequired[pulumi.Input[builtins.str]]
        """
        Unique identifier of the resource in the IAM
        """
        tags: NotRequired[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]
        """
        Resource tags. Tags that were internally computed are prefixed with `ovh:`
        """
        urn: NotRequired[pulumi.Input[builtins.str]]
        """
        URN of the private database, used when writing IAM policies
        """
elif False:
    ServerIamArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerIamArgs:
    def __init__(__self__, *,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 id: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 urn: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] display_name: Resource display name
        :param pulumi.Input[builtins.str] id: Unique identifier of the resource in the IAM
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] tags: Resource tags. Tags that were internally computed are prefixed with `ovh:`
        :param pulumi.Input[builtins.str] urn: URN of the private database, used when writing IAM policies
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if urn is not None:
            pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Unique identifier of the resource in the IAM
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Resource tags. Tags that were internally computed are prefixed with `ovh:`
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def urn(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        URN of the private database, used when writing IAM policies
        """
        return pulumi.get(self, "urn")

    @urn.setter
    def urn(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "urn", value)


if not MYPY:
    class ServerNetworkingInterfaceArgsDict(TypedDict):
        macs: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]
        """
        Interface Mac address
        """
        type: pulumi.Input[builtins.str]
        """
        Interface type
        """
elif False:
    ServerNetworkingInterfaceArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerNetworkingInterfaceArgs:
    def __init__(__self__, *,
                 macs: pulumi.Input[Sequence[pulumi.Input[builtins.str]]],
                 type: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] macs: Interface Mac address
        :param pulumi.Input[builtins.str] type: Interface type
        """
        pulumi.set(__self__, "macs", macs)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def macs(self) -> pulumi.Input[Sequence[pulumi.Input[builtins.str]]]:
        """
        Interface Mac address
        """
        return pulumi.get(self, "macs")

    @macs.setter
    def macs(self, value: pulumi.Input[Sequence[pulumi.Input[builtins.str]]]):
        pulumi.set(self, "macs", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        Interface type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)


if not MYPY:
    class ServerOrderArgsDict(TypedDict):
        date: NotRequired[pulumi.Input[builtins.str]]
        details: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerOrderDetailArgsDict']]]]
        expiration_date: NotRequired[pulumi.Input[builtins.str]]
        order_id: NotRequired[pulumi.Input[builtins.float]]
elif False:
    ServerOrderArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerOrderArgs:
    def __init__(__self__, *,
                 date: Optional[pulumi.Input[builtins.str]] = None,
                 details: Optional[pulumi.Input[Sequence[pulumi.Input['ServerOrderDetailArgs']]]] = None,
                 expiration_date: Optional[pulumi.Input[builtins.str]] = None,
                 order_id: Optional[pulumi.Input[builtins.float]] = None):
        if date is not None:
            pulumi.set(__self__, "date", date)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)

    @property
    @pulumi.getter
    def date(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "date")

    @date.setter
    def date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "date", value)

    @property
    @pulumi.getter
    def details(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerOrderDetailArgs']]]]:
        return pulumi.get(self, "details")

    @details.setter
    def details(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerOrderDetailArgs']]]]):
        pulumi.set(self, "details", value)

    @property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "expiration_date")

    @expiration_date.setter
    def expiration_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expiration_date", value)

    @property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[pulumi.Input[builtins.float]]:
        return pulumi.get(self, "order_id")

    @order_id.setter
    def order_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "order_id", value)


if not MYPY:
    class ServerOrderDetailArgsDict(TypedDict):
        description: NotRequired[pulumi.Input[builtins.str]]
        detail_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Product type of item in order
        """
        domain: NotRequired[pulumi.Input[builtins.str]]
        order_detail_id: NotRequired[pulumi.Input[builtins.float]]
        quantity: NotRequired[pulumi.Input[builtins.str]]
elif False:
    ServerOrderDetailArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerOrderDetailArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 detail_type: Optional[pulumi.Input[builtins.str]] = None,
                 domain: Optional[pulumi.Input[builtins.str]] = None,
                 order_detail_id: Optional[pulumi.Input[builtins.float]] = None,
                 quantity: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] detail_type: Product type of item in order
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if detail_type is not None:
            pulumi.set(__self__, "detail_type", detail_type)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if order_detail_id is not None:
            pulumi.set(__self__, "order_detail_id", order_detail_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="detailType")
    def detail_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Product type of item in order
        """
        return pulumi.get(self, "detail_type")

    @detail_type.setter
    def detail_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "detail_type", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="orderDetailId")
    def order_detail_id(self) -> Optional[pulumi.Input[builtins.float]]:
        return pulumi.get(self, "order_detail_id")

    @order_detail_id.setter
    def order_detail_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "order_detail_id", value)

    @property
    @pulumi.getter
    def quantity(self) -> Optional[pulumi.Input[builtins.str]]:
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "quantity", value)


if not MYPY:
    class ServerPlanArgsDict(TypedDict):
        duration: pulumi.Input[builtins.str]
        """
        Duration selected for the purchase of the product
        """
        plan_code: pulumi.Input[builtins.str]
        """
        Identifier of the option offer
        """
        pricing_mode: pulumi.Input[builtins.str]
        """
        Pricing mode selected for the purchase of the product
        """
        configurations: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerPlanConfigurationArgsDict']]]]
        item_id: NotRequired[pulumi.Input[builtins.float]]
        """
        Cart item to be linked
        """
        quantity: NotRequired[pulumi.Input[builtins.float]]
        """
        Quantity of product desired
        """
elif False:
    ServerPlanArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerPlanArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[builtins.str],
                 plan_code: pulumi.Input[builtins.str],
                 pricing_mode: pulumi.Input[builtins.str],
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanConfigurationArgs']]]] = None,
                 item_id: Optional[pulumi.Input[builtins.float]] = None,
                 quantity: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.str] duration: Duration selected for the purchase of the product
        :param pulumi.Input[builtins.str] plan_code: Identifier of the option offer
        :param pulumi.Input[builtins.str] pricing_mode: Pricing mode selected for the purchase of the product
        :param pulumi.Input[builtins.float] item_id: Cart item to be linked
        :param pulumi.Input[builtins.float] quantity: Quantity of product desired
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)
        if item_id is not None:
            pulumi.set(__self__, "item_id", item_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Input[builtins.str]:
        """
        Duration selected for the purchase of the product
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> pulumi.Input[builtins.str]:
        """
        Identifier of the option offer
        """
        return pulumi.get(self, "plan_code")

    @plan_code.setter
    def plan_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "plan_code", value)

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> pulumi.Input[builtins.str]:
        """
        Pricing mode selected for the purchase of the product
        """
        return pulumi.get(self, "pricing_mode")

    @pricing_mode.setter
    def pricing_mode(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "pricing_mode", value)

    @property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanConfigurationArgs']]]]:
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)

    @property
    @pulumi.getter(name="itemId")
    def item_id(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Cart item to be linked
        """
        return pulumi.get(self, "item_id")

    @item_id.setter
    def item_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "item_id", value)

    @property
    @pulumi.getter
    def quantity(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Quantity of product desired
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "quantity", value)


if not MYPY:
    class ServerPlanConfigurationArgsDict(TypedDict):
        label: pulumi.Input[builtins.str]
        """
        Label for your configuration item
        """
        value: pulumi.Input[builtins.str]
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
elif False:
    ServerPlanConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerPlanConfigurationArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[builtins.str],
                 value: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] label: Label for your configuration item
        :param pulumi.Input[builtins.str] value: Value or resource URL on API.OVH.COM of your configuration item
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> pulumi.Input[builtins.str]:
        """
        Label for your configuration item
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[builtins.str]:
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class ServerPlanOptionArgsDict(TypedDict):
        duration: pulumi.Input[builtins.str]
        """
        Duration selected for the purchase of the product
        """
        plan_code: pulumi.Input[builtins.str]
        """
        Identifier of the option offer
        """
        pricing_mode: pulumi.Input[builtins.str]
        """
        Pricing mode selected for the purchase of the product
        """
        quantity: pulumi.Input[builtins.float]
        """
        Quantity of product desired
        """
        configurations: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionConfigurationArgsDict']]]]
elif False:
    ServerPlanOptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerPlanOptionArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[builtins.str],
                 plan_code: pulumi.Input[builtins.str],
                 pricing_mode: pulumi.Input[builtins.str],
                 quantity: pulumi.Input[builtins.float],
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionConfigurationArgs']]]] = None):
        """
        :param pulumi.Input[builtins.str] duration: Duration selected for the purchase of the product
        :param pulumi.Input[builtins.str] plan_code: Identifier of the option offer
        :param pulumi.Input[builtins.str] pricing_mode: Pricing mode selected for the purchase of the product
        :param pulumi.Input[builtins.float] quantity: Quantity of product desired
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "quantity", quantity)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Input[builtins.str]:
        """
        Duration selected for the purchase of the product
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> pulumi.Input[builtins.str]:
        """
        Identifier of the option offer
        """
        return pulumi.get(self, "plan_code")

    @plan_code.setter
    def plan_code(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "plan_code", value)

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> pulumi.Input[builtins.str]:
        """
        Pricing mode selected for the purchase of the product
        """
        return pulumi.get(self, "pricing_mode")

    @pricing_mode.setter
    def pricing_mode(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "pricing_mode", value)

    @property
    @pulumi.getter
    def quantity(self) -> pulumi.Input[builtins.float]:
        """
        Quantity of product desired
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: pulumi.Input[builtins.float]):
        pulumi.set(self, "quantity", value)

    @property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionConfigurationArgs']]]]:
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)


if not MYPY:
    class ServerPlanOptionConfigurationArgsDict(TypedDict):
        label: pulumi.Input[builtins.str]
        """
        Label for your configuration item
        """
        value: pulumi.Input[builtins.str]
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
elif False:
    ServerPlanOptionConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerPlanOptionConfigurationArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[builtins.str],
                 value: pulumi.Input[builtins.str]):
        """
        :param pulumi.Input[builtins.str] label: Label for your configuration item
        :param pulumi.Input[builtins.str] value: Value or resource URL on API.OVH.COM of your configuration item
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def label(self) -> pulumi.Input[builtins.str]:
        """
        Label for your configuration item
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "label", value)

    @property
    @pulumi.getter
    def value(self) -> pulumi.Input[builtins.str]:
        """
        Value or resource URL on API.OVH.COM of your configuration item
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class ServerReinstallTaskCustomizationsArgsDict(TypedDict):
        config_drive_user_data: NotRequired[pulumi.Input[builtins.str]]
        """
        Config Drive UserData
        """
        efi_bootloader_path: NotRequired[pulumi.Input[builtins.str]]
        """
        EFI bootloader path
        """
        hostname: NotRequired[pulumi.Input[builtins.str]]
        """
        Custom hostname
        """
        http_headers: NotRequired[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]
        """
        Image HTTP Headers
        """
        image_check_sum: NotRequired[pulumi.Input[builtins.str]]
        """
        Image checksum
        """
        image_check_sum_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Checksum type
        """
        image_type: NotRequired[pulumi.Input[builtins.str]]
        """
        Image Type
        """
        image_url: NotRequired[pulumi.Input[builtins.str]]
        """
        Image URL
        """
        language: NotRequired[pulumi.Input[builtins.str]]
        """
        Display Language
        """
        post_installation_script: NotRequired[pulumi.Input[builtins.str]]
        """
        Post-Installation Script
        """
        post_installation_script_extension: NotRequired[pulumi.Input[builtins.str]]
        """
        Post-Installation Script File Extension
        """
        ssh_key: NotRequired[pulumi.Input[builtins.str]]
        """
        SSH Public Key
        """
elif False:
    ServerReinstallTaskCustomizationsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerReinstallTaskCustomizationsArgs:
    def __init__(__self__, *,
                 config_drive_user_data: Optional[pulumi.Input[builtins.str]] = None,
                 efi_bootloader_path: Optional[pulumi.Input[builtins.str]] = None,
                 hostname: Optional[pulumi.Input[builtins.str]] = None,
                 http_headers: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 image_check_sum: Optional[pulumi.Input[builtins.str]] = None,
                 image_check_sum_type: Optional[pulumi.Input[builtins.str]] = None,
                 image_type: Optional[pulumi.Input[builtins.str]] = None,
                 image_url: Optional[pulumi.Input[builtins.str]] = None,
                 language: Optional[pulumi.Input[builtins.str]] = None,
                 post_installation_script: Optional[pulumi.Input[builtins.str]] = None,
                 post_installation_script_extension: Optional[pulumi.Input[builtins.str]] = None,
                 ssh_key: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] config_drive_user_data: Config Drive UserData
        :param pulumi.Input[builtins.str] efi_bootloader_path: EFI bootloader path
        :param pulumi.Input[builtins.str] hostname: Custom hostname
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] http_headers: Image HTTP Headers
        :param pulumi.Input[builtins.str] image_check_sum: Image checksum
        :param pulumi.Input[builtins.str] image_check_sum_type: Checksum type
        :param pulumi.Input[builtins.str] image_type: Image Type
        :param pulumi.Input[builtins.str] image_url: Image URL
        :param pulumi.Input[builtins.str] language: Display Language
        :param pulumi.Input[builtins.str] post_installation_script: Post-Installation Script
        :param pulumi.Input[builtins.str] post_installation_script_extension: Post-Installation Script File Extension
        :param pulumi.Input[builtins.str] ssh_key: SSH Public Key
        """
        if config_drive_user_data is not None:
            pulumi.set(__self__, "config_drive_user_data", config_drive_user_data)
        if efi_bootloader_path is not None:
            pulumi.set(__self__, "efi_bootloader_path", efi_bootloader_path)
        if hostname is not None:
            pulumi.set(__self__, "hostname", hostname)
        if http_headers is not None:
            pulumi.set(__self__, "http_headers", http_headers)
        if image_check_sum is not None:
            pulumi.set(__self__, "image_check_sum", image_check_sum)
        if image_check_sum_type is not None:
            pulumi.set(__self__, "image_check_sum_type", image_check_sum_type)
        if image_type is not None:
            pulumi.set(__self__, "image_type", image_type)
        if image_url is not None:
            pulumi.set(__self__, "image_url", image_url)
        if language is not None:
            pulumi.set(__self__, "language", language)
        if post_installation_script is not None:
            pulumi.set(__self__, "post_installation_script", post_installation_script)
        if post_installation_script_extension is not None:
            pulumi.set(__self__, "post_installation_script_extension", post_installation_script_extension)
        if ssh_key is not None:
            pulumi.set(__self__, "ssh_key", ssh_key)

    @property
    @pulumi.getter(name="configDriveUserData")
    def config_drive_user_data(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Config Drive UserData
        """
        return pulumi.get(self, "config_drive_user_data")

    @config_drive_user_data.setter
    def config_drive_user_data(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "config_drive_user_data", value)

    @property
    @pulumi.getter(name="efiBootloaderPath")
    def efi_bootloader_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        EFI bootloader path
        """
        return pulumi.get(self, "efi_bootloader_path")

    @efi_bootloader_path.setter
    def efi_bootloader_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "efi_bootloader_path", value)

    @property
    @pulumi.getter
    def hostname(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Custom hostname
        """
        return pulumi.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "hostname", value)

    @property
    @pulumi.getter(name="httpHeaders")
    def http_headers(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Image HTTP Headers
        """
        return pulumi.get(self, "http_headers")

    @http_headers.setter
    def http_headers(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "http_headers", value)

    @property
    @pulumi.getter(name="imageCheckSum")
    def image_check_sum(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image checksum
        """
        return pulumi.get(self, "image_check_sum")

    @image_check_sum.setter
    def image_check_sum(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_check_sum", value)

    @property
    @pulumi.getter(name="imageCheckSumType")
    def image_check_sum_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Checksum type
        """
        return pulumi.get(self, "image_check_sum_type")

    @image_check_sum_type.setter
    def image_check_sum_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_check_sum_type", value)

    @property
    @pulumi.getter(name="imageType")
    def image_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image Type
        """
        return pulumi.get(self, "image_type")

    @image_type.setter
    def image_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_type", value)

    @property
    @pulumi.getter(name="imageUrl")
    def image_url(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Image URL
        """
        return pulumi.get(self, "image_url")

    @image_url.setter
    def image_url(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_url", value)

    @property
    @pulumi.getter
    def language(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Display Language
        """
        return pulumi.get(self, "language")

    @language.setter
    def language(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "language", value)

    @property
    @pulumi.getter(name="postInstallationScript")
    def post_installation_script(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Post-Installation Script
        """
        return pulumi.get(self, "post_installation_script")

    @post_installation_script.setter
    def post_installation_script(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "post_installation_script", value)

    @property
    @pulumi.getter(name="postInstallationScriptExtension")
    def post_installation_script_extension(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Post-Installation Script File Extension
        """
        return pulumi.get(self, "post_installation_script_extension")

    @post_installation_script_extension.setter
    def post_installation_script_extension(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "post_installation_script_extension", value)

    @property
    @pulumi.getter(name="sshKey")
    def ssh_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        SSH Public Key
        """
        return pulumi.get(self, "ssh_key")

    @ssh_key.setter
    def ssh_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ssh_key", value)


if not MYPY:
    class ServerReinstallTaskStorageArgsDict(TypedDict):
        disk_group_id: NotRequired[pulumi.Input[builtins.int]]
        """
        Disk group id to install the OS to (default is 0, meaning automatic).
        """
        hardware_raids: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageHardwareRaidArgsDict']]]]
        """
        Hardware Raid configurations (if not specified, all disks of the chosen disk group id will be configured in JBOD mode).
        """
        partitionings: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningArgsDict']]]]
        """
        Partitioning configuration
        """
elif False:
    ServerReinstallTaskStorageArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerReinstallTaskStorageArgs:
    def __init__(__self__, *,
                 disk_group_id: Optional[pulumi.Input[builtins.int]] = None,
                 hardware_raids: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageHardwareRaidArgs']]]] = None,
                 partitionings: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningArgs']]]] = None):
        """
        :param pulumi.Input[builtins.int] disk_group_id: Disk group id to install the OS to (default is 0, meaning automatic).
        :param pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageHardwareRaidArgs']]] hardware_raids: Hardware Raid configurations (if not specified, all disks of the chosen disk group id will be configured in JBOD mode).
        :param pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningArgs']]] partitionings: Partitioning configuration
        """
        if disk_group_id is not None:
            pulumi.set(__self__, "disk_group_id", disk_group_id)
        if hardware_raids is not None:
            pulumi.set(__self__, "hardware_raids", hardware_raids)
        if partitionings is not None:
            pulumi.set(__self__, "partitionings", partitionings)

    @property
    @pulumi.getter(name="diskGroupId")
    def disk_group_id(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Disk group id to install the OS to (default is 0, meaning automatic).
        """
        return pulumi.get(self, "disk_group_id")

    @disk_group_id.setter
    def disk_group_id(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "disk_group_id", value)

    @property
    @pulumi.getter(name="hardwareRaids")
    def hardware_raids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageHardwareRaidArgs']]]]:
        """
        Hardware Raid configurations (if not specified, all disks of the chosen disk group id will be configured in JBOD mode).
        """
        return pulumi.get(self, "hardware_raids")

    @hardware_raids.setter
    def hardware_raids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStorageHardwareRaidArgs']]]]):
        pulumi.set(self, "hardware_raids", value)

    @property
    @pulumi.getter
    def partitionings(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningArgs']]]]:
        """
        Partitioning configuration
        """
        return pulumi.get(self, "partitionings")

    @partitionings.setter
    def partitionings(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningArgs']]]]):
        pulumi.set(self, "partitionings", value)


if not MYPY:
    class ServerReinstallTaskStorageHardwareRaidArgsDict(TypedDict):
        arrays: NotRequired[pulumi.Input[builtins.int]]
        """
        Number of arrays (default is 1)
        """
        disks: NotRequired[pulumi.Input[builtins.int]]
        """
        Total number of disks in the disk group involved in the hardware raid configuration (all disks of the disk group by default)
        """
        raid_level: NotRequired[pulumi.Input[builtins.int]]
        """
        Hardware raid type (default is 1)
        """
        spares: NotRequired[pulumi.Input[builtins.int]]
        """
        Number of disks in the disk group involved in the spare (default is 0)
        """
elif False:
    ServerReinstallTaskStorageHardwareRaidArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerReinstallTaskStorageHardwareRaidArgs:
    def __init__(__self__, *,
                 arrays: Optional[pulumi.Input[builtins.int]] = None,
                 disks: Optional[pulumi.Input[builtins.int]] = None,
                 raid_level: Optional[pulumi.Input[builtins.int]] = None,
                 spares: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] arrays: Number of arrays (default is 1)
        :param pulumi.Input[builtins.int] disks: Total number of disks in the disk group involved in the hardware raid configuration (all disks of the disk group by default)
        :param pulumi.Input[builtins.int] raid_level: Hardware raid type (default is 1)
        :param pulumi.Input[builtins.int] spares: Number of disks in the disk group involved in the spare (default is 0)
        """
        if arrays is not None:
            pulumi.set(__self__, "arrays", arrays)
        if disks is not None:
            pulumi.set(__self__, "disks", disks)
        if raid_level is not None:
            pulumi.set(__self__, "raid_level", raid_level)
        if spares is not None:
            pulumi.set(__self__, "spares", spares)

    @property
    @pulumi.getter
    def arrays(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of arrays (default is 1)
        """
        return pulumi.get(self, "arrays")

    @arrays.setter
    def arrays(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "arrays", value)

    @property
    @pulumi.getter
    def disks(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Total number of disks in the disk group involved in the hardware raid configuration (all disks of the disk group by default)
        """
        return pulumi.get(self, "disks")

    @disks.setter
    def disks(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "disks", value)

    @property
    @pulumi.getter(name="raidLevel")
    def raid_level(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Hardware raid type (default is 1)
        """
        return pulumi.get(self, "raid_level")

    @raid_level.setter
    def raid_level(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "raid_level", value)

    @property
    @pulumi.getter
    def spares(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of disks in the disk group involved in the spare (default is 0)
        """
        return pulumi.get(self, "spares")

    @spares.setter
    def spares(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "spares", value)


if not MYPY:
    class ServerReinstallTaskStoragePartitioningArgsDict(TypedDict):
        disks: NotRequired[pulumi.Input[builtins.int]]
        """
        Total number of disks in the disk group involved in the partitioning configuration (all disks of the disk group by default)
        """
        layouts: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutArgsDict']]]]
        """
        Custom partitioning layout (default is the default layout of the operating system's default partitioning scheme). Accept multiple values (multiple partitions):
        """
        scheme_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Partitioning scheme (if applicable with selected operating system)
        """
elif False:
    ServerReinstallTaskStoragePartitioningArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerReinstallTaskStoragePartitioningArgs:
    def __init__(__self__, *,
                 disks: Optional[pulumi.Input[builtins.int]] = None,
                 layouts: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutArgs']]]] = None,
                 scheme_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.int] disks: Total number of disks in the disk group involved in the partitioning configuration (all disks of the disk group by default)
        :param pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutArgs']]] layouts: Custom partitioning layout (default is the default layout of the operating system's default partitioning scheme). Accept multiple values (multiple partitions):
        :param pulumi.Input[builtins.str] scheme_name: Partitioning scheme (if applicable with selected operating system)
        """
        if disks is not None:
            pulumi.set(__self__, "disks", disks)
        if layouts is not None:
            pulumi.set(__self__, "layouts", layouts)
        if scheme_name is not None:
            pulumi.set(__self__, "scheme_name", scheme_name)

    @property
    @pulumi.getter
    def disks(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Total number of disks in the disk group involved in the partitioning configuration (all disks of the disk group by default)
        """
        return pulumi.get(self, "disks")

    @disks.setter
    def disks(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "disks", value)

    @property
    @pulumi.getter
    def layouts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutArgs']]]]:
        """
        Custom partitioning layout (default is the default layout of the operating system's default partitioning scheme). Accept multiple values (multiple partitions):
        """
        return pulumi.get(self, "layouts")

    @layouts.setter
    def layouts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutArgs']]]]):
        pulumi.set(self, "layouts", value)

    @property
    @pulumi.getter(name="schemeName")
    def scheme_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Partitioning scheme (if applicable with selected operating system)
        """
        return pulumi.get(self, "scheme_name")

    @scheme_name.setter
    def scheme_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheme_name", value)


if not MYPY:
    class ServerReinstallTaskStoragePartitioningLayoutArgsDict(TypedDict):
        file_system: pulumi.Input[builtins.str]
        """
        File system type
        """
        mount_point: pulumi.Input[builtins.str]
        """
        Mount point
        """
        extras: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraArgsDict']]]]
        """
        Partition extras parameters (when applicable)
        """
        raid_level: NotRequired[pulumi.Input[builtins.int]]
        """
        Software raid type (default is 1)
        """
        size: NotRequired[pulumi.Input[builtins.int]]
        """
        Partition size in MiB (default value is 0 which means to fill the disk with that partition)
        """
elif False:
    ServerReinstallTaskStoragePartitioningLayoutArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerReinstallTaskStoragePartitioningLayoutArgs:
    def __init__(__self__, *,
                 file_system: pulumi.Input[builtins.str],
                 mount_point: pulumi.Input[builtins.str],
                 extras: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraArgs']]]] = None,
                 raid_level: Optional[pulumi.Input[builtins.int]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.str] file_system: File system type
        :param pulumi.Input[builtins.str] mount_point: Mount point
        :param pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraArgs']]] extras: Partition extras parameters (when applicable)
        :param pulumi.Input[builtins.int] raid_level: Software raid type (default is 1)
        :param pulumi.Input[builtins.int] size: Partition size in MiB (default value is 0 which means to fill the disk with that partition)
        """
        pulumi.set(__self__, "file_system", file_system)
        pulumi.set(__self__, "mount_point", mount_point)
        if extras is not None:
            pulumi.set(__self__, "extras", extras)
        if raid_level is not None:
            pulumi.set(__self__, "raid_level", raid_level)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter(name="fileSystem")
    def file_system(self) -> pulumi.Input[builtins.str]:
        """
        File system type
        """
        return pulumi.get(self, "file_system")

    @file_system.setter
    def file_system(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "file_system", value)

    @property
    @pulumi.getter(name="mountPoint")
    def mount_point(self) -> pulumi.Input[builtins.str]:
        """
        Mount point
        """
        return pulumi.get(self, "mount_point")

    @mount_point.setter
    def mount_point(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "mount_point", value)

    @property
    @pulumi.getter
    def extras(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraArgs']]]]:
        """
        Partition extras parameters (when applicable)
        """
        return pulumi.get(self, "extras")

    @extras.setter
    def extras(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraArgs']]]]):
        pulumi.set(self, "extras", value)

    @property
    @pulumi.getter(name="raidLevel")
    def raid_level(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Software raid type (default is 1)
        """
        return pulumi.get(self, "raid_level")

    @raid_level.setter
    def raid_level(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "raid_level", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Partition size in MiB (default value is 0 which means to fill the disk with that partition)
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)


if not MYPY:
    class ServerReinstallTaskStoragePartitioningLayoutExtraArgsDict(TypedDict):
        lvs: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraLvArgsDict']]]]
        """
        LVM-specific parameters (when applicable)
        """
        zps: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraZpArgsDict']]]]
        """
        ZFS-specific parameters (when applicable)
        """
elif False:
    ServerReinstallTaskStoragePartitioningLayoutExtraArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerReinstallTaskStoragePartitioningLayoutExtraArgs:
    def __init__(__self__, *,
                 lvs: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraLvArgs']]]] = None,
                 zps: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraZpArgs']]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraLvArgs']]] lvs: LVM-specific parameters (when applicable)
        :param pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraZpArgs']]] zps: ZFS-specific parameters (when applicable)
        """
        if lvs is not None:
            pulumi.set(__self__, "lvs", lvs)
        if zps is not None:
            pulumi.set(__self__, "zps", zps)

    @property
    @pulumi.getter
    def lvs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraLvArgs']]]]:
        """
        LVM-specific parameters (when applicable)
        """
        return pulumi.get(self, "lvs")

    @lvs.setter
    def lvs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraLvArgs']]]]):
        pulumi.set(self, "lvs", value)

    @property
    @pulumi.getter
    def zps(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraZpArgs']]]]:
        """
        ZFS-specific parameters (when applicable)
        """
        return pulumi.get(self, "zps")

    @zps.setter
    def zps(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerReinstallTaskStoragePartitioningLayoutExtraZpArgs']]]]):
        pulumi.set(self, "zps", value)


if not MYPY:
    class ServerReinstallTaskStoragePartitioningLayoutExtraLvArgsDict(TypedDict):
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        Logical volume name
        """
elif False:
    ServerReinstallTaskStoragePartitioningLayoutExtraLvArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerReinstallTaskStoragePartitioningLayoutExtraLvArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] name: Logical volume name
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Logical volume name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class ServerReinstallTaskStoragePartitioningLayoutExtraZpArgsDict(TypedDict):
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        zpool name (generated automatically if not specified, note that multiple ZFS partitions with same zpool names will be configured as multiple datasets belonging to the same zpool if compatible)
        """
elif False:
    ServerReinstallTaskStoragePartitioningLayoutExtraZpArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerReinstallTaskStoragePartitioningLayoutExtraZpArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] name: zpool name (generated automatically if not specified, note that multiple ZFS partitions with same zpool names will be configured as multiple datasets belonging to the same zpool if compatible)
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        zpool name (generated automatically if not specified, note that multiple ZFS partitions with same zpool names will be configured as multiple datasets belonging to the same zpool if compatible)
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class ServerStorageArgsDict(TypedDict):
        disk_group_id: NotRequired[pulumi.Input[builtins.float]]
        """
        Disk group id (default is 0, meaning automatic)
        """
        hardware_raids: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerStorageHardwareRaidArgsDict']]]]
        """
        Hardware Raid configurations (if not specified, all disks of the chosen disk group id will be configured in JBOD mode)
        """
        partitioning: NotRequired[pulumi.Input['ServerStoragePartitioningArgsDict']]
        """
        Partitioning configuration
        """
elif False:
    ServerStorageArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerStorageArgs:
    def __init__(__self__, *,
                 disk_group_id: Optional[pulumi.Input[builtins.float]] = None,
                 hardware_raids: Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageHardwareRaidArgs']]]] = None,
                 partitioning: Optional[pulumi.Input['ServerStoragePartitioningArgs']] = None):
        """
        :param pulumi.Input[builtins.float] disk_group_id: Disk group id (default is 0, meaning automatic)
        :param pulumi.Input[Sequence[pulumi.Input['ServerStorageHardwareRaidArgs']]] hardware_raids: Hardware Raid configurations (if not specified, all disks of the chosen disk group id will be configured in JBOD mode)
        :param pulumi.Input['ServerStoragePartitioningArgs'] partitioning: Partitioning configuration
        """
        if disk_group_id is not None:
            pulumi.set(__self__, "disk_group_id", disk_group_id)
        if hardware_raids is not None:
            pulumi.set(__self__, "hardware_raids", hardware_raids)
        if partitioning is not None:
            pulumi.set(__self__, "partitioning", partitioning)

    @property
    @pulumi.getter(name="diskGroupId")
    def disk_group_id(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Disk group id (default is 0, meaning automatic)
        """
        return pulumi.get(self, "disk_group_id")

    @disk_group_id.setter
    def disk_group_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "disk_group_id", value)

    @property
    @pulumi.getter(name="hardwareRaids")
    def hardware_raids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageHardwareRaidArgs']]]]:
        """
        Hardware Raid configurations (if not specified, all disks of the chosen disk group id will be configured in JBOD mode)
        """
        return pulumi.get(self, "hardware_raids")

    @hardware_raids.setter
    def hardware_raids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageHardwareRaidArgs']]]]):
        pulumi.set(self, "hardware_raids", value)

    @property
    @pulumi.getter
    def partitioning(self) -> Optional[pulumi.Input['ServerStoragePartitioningArgs']]:
        """
        Partitioning configuration
        """
        return pulumi.get(self, "partitioning")

    @partitioning.setter
    def partitioning(self, value: Optional[pulumi.Input['ServerStoragePartitioningArgs']]):
        pulumi.set(self, "partitioning", value)


if not MYPY:
    class ServerStorageHardwareRaidArgsDict(TypedDict):
        arrays: NotRequired[pulumi.Input[builtins.float]]
        """
        Number of arrays (default is 1)
        """
        disks: NotRequired[pulumi.Input[builtins.float]]
        """
        Total number of disks in the disk group involved in the hardware raid configuration (all disks of the disk group by default)
        """
        raid_level: NotRequired[pulumi.Input[builtins.float]]
        """
        Hardware raid type (default is 1)
        """
        spares: NotRequired[pulumi.Input[builtins.float]]
        """
        Number of disks in the disk group involved in the spare (default is 0)
        """
elif False:
    ServerStorageHardwareRaidArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerStorageHardwareRaidArgs:
    def __init__(__self__, *,
                 arrays: Optional[pulumi.Input[builtins.float]] = None,
                 disks: Optional[pulumi.Input[builtins.float]] = None,
                 raid_level: Optional[pulumi.Input[builtins.float]] = None,
                 spares: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.float] arrays: Number of arrays (default is 1)
        :param pulumi.Input[builtins.float] disks: Total number of disks in the disk group involved in the hardware raid configuration (all disks of the disk group by default)
        :param pulumi.Input[builtins.float] raid_level: Hardware raid type (default is 1)
        :param pulumi.Input[builtins.float] spares: Number of disks in the disk group involved in the spare (default is 0)
        """
        if arrays is not None:
            pulumi.set(__self__, "arrays", arrays)
        if disks is not None:
            pulumi.set(__self__, "disks", disks)
        if raid_level is not None:
            pulumi.set(__self__, "raid_level", raid_level)
        if spares is not None:
            pulumi.set(__self__, "spares", spares)

    @property
    @pulumi.getter
    def arrays(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Number of arrays (default is 1)
        """
        return pulumi.get(self, "arrays")

    @arrays.setter
    def arrays(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "arrays", value)

    @property
    @pulumi.getter
    def disks(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Total number of disks in the disk group involved in the hardware raid configuration (all disks of the disk group by default)
        """
        return pulumi.get(self, "disks")

    @disks.setter
    def disks(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "disks", value)

    @property
    @pulumi.getter(name="raidLevel")
    def raid_level(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Hardware raid type (default is 1)
        """
        return pulumi.get(self, "raid_level")

    @raid_level.setter
    def raid_level(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "raid_level", value)

    @property
    @pulumi.getter
    def spares(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Number of disks in the disk group involved in the spare (default is 0)
        """
        return pulumi.get(self, "spares")

    @spares.setter
    def spares(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "spares", value)


if not MYPY:
    class ServerStoragePartitioningArgsDict(TypedDict):
        disks: NotRequired[pulumi.Input[builtins.float]]
        """
        Total number of disks in the disk group involved in the partitioning configuration (all disks of the disk group by default)
        """
        layouts: NotRequired[pulumi.Input[Sequence[pulumi.Input['ServerStoragePartitioningLayoutArgsDict']]]]
        """
        Custom partitioning layout (default is the default layout of the operating system's default partitioning scheme)
        """
        scheme_name: NotRequired[pulumi.Input[builtins.str]]
        """
        Partitioning scheme (if applicable with selected operating system)
        """
elif False:
    ServerStoragePartitioningArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerStoragePartitioningArgs:
    def __init__(__self__, *,
                 disks: Optional[pulumi.Input[builtins.float]] = None,
                 layouts: Optional[pulumi.Input[Sequence[pulumi.Input['ServerStoragePartitioningLayoutArgs']]]] = None,
                 scheme_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.float] disks: Total number of disks in the disk group involved in the partitioning configuration (all disks of the disk group by default)
        :param pulumi.Input[Sequence[pulumi.Input['ServerStoragePartitioningLayoutArgs']]] layouts: Custom partitioning layout (default is the default layout of the operating system's default partitioning scheme)
        :param pulumi.Input[builtins.str] scheme_name: Partitioning scheme (if applicable with selected operating system)
        """
        if disks is not None:
            pulumi.set(__self__, "disks", disks)
        if layouts is not None:
            pulumi.set(__self__, "layouts", layouts)
        if scheme_name is not None:
            pulumi.set(__self__, "scheme_name", scheme_name)

    @property
    @pulumi.getter
    def disks(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Total number of disks in the disk group involved in the partitioning configuration (all disks of the disk group by default)
        """
        return pulumi.get(self, "disks")

    @disks.setter
    def disks(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "disks", value)

    @property
    @pulumi.getter
    def layouts(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerStoragePartitioningLayoutArgs']]]]:
        """
        Custom partitioning layout (default is the default layout of the operating system's default partitioning scheme)
        """
        return pulumi.get(self, "layouts")

    @layouts.setter
    def layouts(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerStoragePartitioningLayoutArgs']]]]):
        pulumi.set(self, "layouts", value)

    @property
    @pulumi.getter(name="schemeName")
    def scheme_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Partitioning scheme (if applicable with selected operating system)
        """
        return pulumi.get(self, "scheme_name")

    @scheme_name.setter
    def scheme_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "scheme_name", value)


if not MYPY:
    class ServerStoragePartitioningLayoutArgsDict(TypedDict):
        file_system: pulumi.Input[builtins.str]
        """
        File system type
        """
        mount_point: pulumi.Input[builtins.str]
        """
        Mount point
        """
        extras: NotRequired[pulumi.Input['ServerStoragePartitioningLayoutExtrasArgsDict']]
        """
        Partition extras parameters
        """
        raid_level: NotRequired[pulumi.Input[builtins.float]]
        """
        Software raid type (default is 1)
        """
        size: NotRequired[pulumi.Input[builtins.float]]
        """
        Partition size in MiB (default value is 0 which means to fill the disk with that partition)
        """
elif False:
    ServerStoragePartitioningLayoutArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerStoragePartitioningLayoutArgs:
    def __init__(__self__, *,
                 file_system: pulumi.Input[builtins.str],
                 mount_point: pulumi.Input[builtins.str],
                 extras: Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasArgs']] = None,
                 raid_level: Optional[pulumi.Input[builtins.float]] = None,
                 size: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.str] file_system: File system type
        :param pulumi.Input[builtins.str] mount_point: Mount point
        :param pulumi.Input['ServerStoragePartitioningLayoutExtrasArgs'] extras: Partition extras parameters
        :param pulumi.Input[builtins.float] raid_level: Software raid type (default is 1)
        :param pulumi.Input[builtins.float] size: Partition size in MiB (default value is 0 which means to fill the disk with that partition)
        """
        pulumi.set(__self__, "file_system", file_system)
        pulumi.set(__self__, "mount_point", mount_point)
        if extras is not None:
            pulumi.set(__self__, "extras", extras)
        if raid_level is not None:
            pulumi.set(__self__, "raid_level", raid_level)
        if size is not None:
            pulumi.set(__self__, "size", size)

    @property
    @pulumi.getter(name="fileSystem")
    def file_system(self) -> pulumi.Input[builtins.str]:
        """
        File system type
        """
        return pulumi.get(self, "file_system")

    @file_system.setter
    def file_system(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "file_system", value)

    @property
    @pulumi.getter(name="mountPoint")
    def mount_point(self) -> pulumi.Input[builtins.str]:
        """
        Mount point
        """
        return pulumi.get(self, "mount_point")

    @mount_point.setter
    def mount_point(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "mount_point", value)

    @property
    @pulumi.getter
    def extras(self) -> Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasArgs']]:
        """
        Partition extras parameters
        """
        return pulumi.get(self, "extras")

    @extras.setter
    def extras(self, value: Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasArgs']]):
        pulumi.set(self, "extras", value)

    @property
    @pulumi.getter(name="raidLevel")
    def raid_level(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Software raid type (default is 1)
        """
        return pulumi.get(self, "raid_level")

    @raid_level.setter
    def raid_level(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "raid_level", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Partition size in MiB (default value is 0 which means to fill the disk with that partition)
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "size", value)


if not MYPY:
    class ServerStoragePartitioningLayoutExtrasArgsDict(TypedDict):
        lv: NotRequired[pulumi.Input['ServerStoragePartitioningLayoutExtrasLvArgsDict']]
        """
        LVM-specific parameters
        """
        zp: NotRequired[pulumi.Input['ServerStoragePartitioningLayoutExtrasZpArgsDict']]
        """
        ZFS-specific parameters
        """
elif False:
    ServerStoragePartitioningLayoutExtrasArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerStoragePartitioningLayoutExtrasArgs:
    def __init__(__self__, *,
                 lv: Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasLvArgs']] = None,
                 zp: Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasZpArgs']] = None):
        """
        :param pulumi.Input['ServerStoragePartitioningLayoutExtrasLvArgs'] lv: LVM-specific parameters
        :param pulumi.Input['ServerStoragePartitioningLayoutExtrasZpArgs'] zp: ZFS-specific parameters
        """
        if lv is not None:
            pulumi.set(__self__, "lv", lv)
        if zp is not None:
            pulumi.set(__self__, "zp", zp)

    @property
    @pulumi.getter
    def lv(self) -> Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasLvArgs']]:
        """
        LVM-specific parameters
        """
        return pulumi.get(self, "lv")

    @lv.setter
    def lv(self, value: Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasLvArgs']]):
        pulumi.set(self, "lv", value)

    @property
    @pulumi.getter
    def zp(self) -> Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasZpArgs']]:
        """
        ZFS-specific parameters
        """
        return pulumi.get(self, "zp")

    @zp.setter
    def zp(self, value: Optional[pulumi.Input['ServerStoragePartitioningLayoutExtrasZpArgs']]):
        pulumi.set(self, "zp", value)


if not MYPY:
    class ServerStoragePartitioningLayoutExtrasLvArgsDict(TypedDict):
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        Dedicated server name
        """
elif False:
    ServerStoragePartitioningLayoutExtrasLvArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerStoragePartitioningLayoutExtrasLvArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] name: Dedicated server name
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated server name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


if not MYPY:
    class ServerStoragePartitioningLayoutExtrasZpArgsDict(TypedDict):
        name: NotRequired[pulumi.Input[builtins.str]]
        """
        Dedicated server name
        """
elif False:
    ServerStoragePartitioningLayoutExtrasZpArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ServerStoragePartitioningLayoutExtrasZpArgs:
    def __init__(__self__, *,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] name: Dedicated server name
        """
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated server name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCartProductOptionsPlanPriceResult',
    'GetCartProductOptionsPlanPricePriceResult',
    'GetCartProductOptionsPlanSelectedPriceResult',
    'GetCartProductOptionsPlanSelectedPricePriceResult',
    'GetCartProductOptionsResultResult',
    'GetCartProductOptionsResultPriceResult',
    'GetCartProductOptionsResultPricePriceResult',
    'GetCartProductPlanPriceResult',
    'GetCartProductPlanPricePriceResult',
    'GetCartProductPlanSelectedPriceResult',
    'GetCartProductPlanSelectedPricePriceResult',
    'GetCartProductResultResult',
    'GetCartProductResultPriceResult',
    'GetCartProductResultPricePriceResult',
]

@pulumi.output_type
class GetCartProductOptionsPlanPriceResult(dict):
    def __init__(__self__, *,
                 capacities: Sequence[Any],
                 description: builtins.str,
                 duration: builtins.str,
                 interval: builtins.int,
                 maximum_quantity: builtins.int,
                 maximum_repeat: builtins.int,
                 minimum_quantity: builtins.int,
                 minimum_repeat: builtins.int,
                 price_in_ucents: builtins.int,
                 prices: Sequence['outputs.GetCartProductOptionsPlanPricePriceResult'],
                 pricing_mode: builtins.str,
                 pricing_type: builtins.str):
        """
        :param Sequence[Any] capacities: Capacities of the pricing (type of pricing)
        :param builtins.str description: Description of the pricing
        :param builtins.str duration: Duration for ordering the product
        :param builtins.int interval: Interval of renewal
        :param builtins.int maximum_quantity: Maximum quantity that can be ordered
        :param builtins.int maximum_repeat: Maximum repeat for renewal
        :param builtins.int minimum_quantity: Minimum quantity that can be ordered
        :param builtins.int minimum_repeat: Minimum repeat for renewal
        :param builtins.int price_in_ucents: Price of the product in micro-centims
        :param Sequence['GetCartProductOptionsPlanPricePriceArgs'] prices: Price of the product (Price with its currency and textual representation)
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str pricing_type: Pricing type
        """
        pulumi.set(__self__, "capacities", capacities)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "interval", interval)
        pulumi.set(__self__, "maximum_quantity", maximum_quantity)
        pulumi.set(__self__, "maximum_repeat", maximum_repeat)
        pulumi.set(__self__, "minimum_quantity", minimum_quantity)
        pulumi.set(__self__, "minimum_repeat", minimum_repeat)
        pulumi.set(__self__, "price_in_ucents", price_in_ucents)
        pulumi.set(__self__, "prices", prices)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "pricing_type", pricing_type)

    @property
    @pulumi.getter
    def capacities(self) -> Sequence[Any]:
        """
        Capacities of the pricing (type of pricing)
        """
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the pricing
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Duration for ordering the product
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def interval(self) -> builtins.int:
        """
        Interval of renewal
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="maximumQuantity")
    def maximum_quantity(self) -> builtins.int:
        """
        Maximum quantity that can be ordered
        """
        return pulumi.get(self, "maximum_quantity")

    @property
    @pulumi.getter(name="maximumRepeat")
    def maximum_repeat(self) -> builtins.int:
        """
        Maximum repeat for renewal
        """
        return pulumi.get(self, "maximum_repeat")

    @property
    @pulumi.getter(name="minimumQuantity")
    def minimum_quantity(self) -> builtins.int:
        """
        Minimum quantity that can be ordered
        """
        return pulumi.get(self, "minimum_quantity")

    @property
    @pulumi.getter(name="minimumRepeat")
    def minimum_repeat(self) -> builtins.int:
        """
        Minimum repeat for renewal
        """
        return pulumi.get(self, "minimum_repeat")

    @property
    @pulumi.getter(name="priceInUcents")
    def price_in_ucents(self) -> builtins.int:
        """
        Price of the product in micro-centims
        """
        return pulumi.get(self, "price_in_ucents")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetCartProductOptionsPlanPricePriceResult']:
        """
        Price of the product (Price with its currency and textual representation)
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="pricingType")
    def pricing_type(self) -> builtins.str:
        """
        Pricing type
        """
        return pulumi.get(self, "pricing_type")


@pulumi.output_type
class GetCartProductOptionsPlanPricePriceResult(dict):
    def __init__(__self__, *,
                 currency_code: builtins.str,
                 text: builtins.str,
                 value: builtins.float):
        """
        :param builtins.str currency_code: Currency code
        :param builtins.str text: Textual representation
        :param builtins.float value: The effective price
        """
        pulumi.set(__self__, "currency_code", currency_code)
        pulumi.set(__self__, "text", text)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="currencyCode")
    def currency_code(self) -> builtins.str:
        """
        Currency code
        """
        return pulumi.get(self, "currency_code")

    @property
    @pulumi.getter
    def text(self) -> builtins.str:
        """
        Textual representation
        """
        return pulumi.get(self, "text")

    @property
    @pulumi.getter
    def value(self) -> builtins.float:
        """
        The effective price
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetCartProductOptionsPlanSelectedPriceResult(dict):
    def __init__(__self__, *,
                 capacities: Sequence[Any],
                 description: builtins.str,
                 duration: builtins.str,
                 interval: builtins.int,
                 maximum_quantity: builtins.int,
                 maximum_repeat: builtins.int,
                 minimum_quantity: builtins.int,
                 minimum_repeat: builtins.int,
                 price_in_ucents: builtins.int,
                 prices: Sequence['outputs.GetCartProductOptionsPlanSelectedPricePriceResult'],
                 pricing_mode: builtins.str,
                 pricing_type: builtins.str):
        """
        :param Sequence[Any] capacities: Capacities of the pricing (type of pricing)
        :param builtins.str description: Description of the pricing
        :param builtins.str duration: Duration for ordering the product
        :param builtins.int interval: Interval of renewal
        :param builtins.int maximum_quantity: Maximum quantity that can be ordered
        :param builtins.int maximum_repeat: Maximum repeat for renewal
        :param builtins.int minimum_quantity: Minimum quantity that can be ordered
        :param builtins.int minimum_repeat: Minimum repeat for renewal
        :param builtins.int price_in_ucents: Price of the product in micro-centims
        :param Sequence['GetCartProductOptionsPlanSelectedPricePriceArgs'] prices: Price of the product (Price with its currency and textual representation)
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str pricing_type: Pricing type
        """
        pulumi.set(__self__, "capacities", capacities)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "interval", interval)
        pulumi.set(__self__, "maximum_quantity", maximum_quantity)
        pulumi.set(__self__, "maximum_repeat", maximum_repeat)
        pulumi.set(__self__, "minimum_quantity", minimum_quantity)
        pulumi.set(__self__, "minimum_repeat", minimum_repeat)
        pulumi.set(__self__, "price_in_ucents", price_in_ucents)
        pulumi.set(__self__, "prices", prices)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "pricing_type", pricing_type)

    @property
    @pulumi.getter
    def capacities(self) -> Sequence[Any]:
        """
        Capacities of the pricing (type of pricing)
        """
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the pricing
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Duration for ordering the product
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def interval(self) -> builtins.int:
        """
        Interval of renewal
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="maximumQuantity")
    def maximum_quantity(self) -> builtins.int:
        """
        Maximum quantity that can be ordered
        """
        return pulumi.get(self, "maximum_quantity")

    @property
    @pulumi.getter(name="maximumRepeat")
    def maximum_repeat(self) -> builtins.int:
        """
        Maximum repeat for renewal
        """
        return pulumi.get(self, "maximum_repeat")

    @property
    @pulumi.getter(name="minimumQuantity")
    def minimum_quantity(self) -> builtins.int:
        """
        Minimum quantity that can be ordered
        """
        return pulumi.get(self, "minimum_quantity")

    @property
    @pulumi.getter(name="minimumRepeat")
    def minimum_repeat(self) -> builtins.int:
        """
        Minimum repeat for renewal
        """
        return pulumi.get(self, "minimum_repeat")

    @property
    @pulumi.getter(name="priceInUcents")
    def price_in_ucents(self) -> builtins.int:
        """
        Price of the product in micro-centims
        """
        return pulumi.get(self, "price_in_ucents")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetCartProductOptionsPlanSelectedPricePriceResult']:
        """
        Price of the product (Price with its currency and textual representation)
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="pricingType")
    def pricing_type(self) -> builtins.str:
        """
        Pricing type
        """
        return pulumi.get(self, "pricing_type")


@pulumi.output_type
class GetCartProductOptionsPlanSelectedPricePriceResult(dict):
    def __init__(__self__, *,
                 currency_code: builtins.str,
                 text: builtins.str,
                 value: builtins.float):
        """
        :param builtins.str currency_code: Currency code
        :param builtins.str text: Textual representation
        :param builtins.float value: The effective price
        """
        pulumi.set(__self__, "currency_code", currency_code)
        pulumi.set(__self__, "text", text)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="currencyCode")
    def currency_code(self) -> builtins.str:
        """
        Currency code
        """
        return pulumi.get(self, "currency_code")

    @property
    @pulumi.getter
    def text(self) -> builtins.str:
        """
        Textual representation
        """
        return pulumi.get(self, "text")

    @property
    @pulumi.getter
    def value(self) -> builtins.float:
        """
        The effective price
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetCartProductOptionsResultResult(dict):
    def __init__(__self__, *,
                 exclusive: builtins.bool,
                 family: builtins.str,
                 mandatory: builtins.bool,
                 plan_code: builtins.str,
                 prices: Sequence['outputs.GetCartProductOptionsResultPriceResult'],
                 product_name: builtins.str,
                 product_type: builtins.str):
        """
        :param builtins.bool exclusive: Define if options of this family are exclusive with each other
        :param builtins.str family: Option family
        :param builtins.bool mandatory: Define if an option of this family is mandatory
        :param builtins.str plan_code: Product offer identifier
        :param Sequence['GetCartProductOptionsResultPriceArgs'] prices: Prices of the product offer
        :param builtins.str product_name: Name of the product
        :param builtins.str product_type: Product type
        """
        pulumi.set(__self__, "exclusive", exclusive)
        pulumi.set(__self__, "family", family)
        pulumi.set(__self__, "mandatory", mandatory)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "prices", prices)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "product_type", product_type)

    @property
    @pulumi.getter
    def exclusive(self) -> builtins.bool:
        """
        Define if options of this family are exclusive with each other
        """
        return pulumi.get(self, "exclusive")

    @property
    @pulumi.getter
    def family(self) -> builtins.str:
        """
        Option family
        """
        return pulumi.get(self, "family")

    @property
    @pulumi.getter
    def mandatory(self) -> builtins.bool:
        """
        Define if an option of this family is mandatory
        """
        return pulumi.get(self, "mandatory")

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Product offer identifier
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetCartProductOptionsResultPriceResult']:
        """
        Prices of the product offer
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> builtins.str:
        """
        Name of the product
        """
        return pulumi.get(self, "product_name")

    @property
    @pulumi.getter(name="productType")
    def product_type(self) -> builtins.str:
        """
        Product type
        """
        return pulumi.get(self, "product_type")


@pulumi.output_type
class GetCartProductOptionsResultPriceResult(dict):
    def __init__(__self__, *,
                 capacities: Sequence[Any],
                 description: builtins.str,
                 duration: builtins.str,
                 interval: builtins.int,
                 maximum_quantity: builtins.int,
                 maximum_repeat: builtins.int,
                 minimum_quantity: builtins.int,
                 minimum_repeat: builtins.int,
                 price_in_ucents: builtins.int,
                 prices: Sequence['outputs.GetCartProductOptionsResultPricePriceResult'],
                 pricing_mode: builtins.str,
                 pricing_type: builtins.str):
        """
        :param Sequence[Any] capacities: Capacities of the pricing (type of pricing)
        :param builtins.str description: Description of the pricing
        :param builtins.str duration: Duration for ordering the product
        :param builtins.int interval: Interval of renewal
        :param builtins.int maximum_quantity: Maximum quantity that can be ordered
        :param builtins.int maximum_repeat: Maximum repeat for renewal
        :param builtins.int minimum_quantity: Minimum quantity that can be ordered
        :param builtins.int minimum_repeat: Minimum repeat for renewal
        :param builtins.int price_in_ucents: Price of the product in micro-centims
        :param Sequence['GetCartProductOptionsResultPricePriceArgs'] prices: Price of the product (Price with its currency and textual representation)
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str pricing_type: Pricing type
        """
        pulumi.set(__self__, "capacities", capacities)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "interval", interval)
        pulumi.set(__self__, "maximum_quantity", maximum_quantity)
        pulumi.set(__self__, "maximum_repeat", maximum_repeat)
        pulumi.set(__self__, "minimum_quantity", minimum_quantity)
        pulumi.set(__self__, "minimum_repeat", minimum_repeat)
        pulumi.set(__self__, "price_in_ucents", price_in_ucents)
        pulumi.set(__self__, "prices", prices)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "pricing_type", pricing_type)

    @property
    @pulumi.getter
    def capacities(self) -> Sequence[Any]:
        """
        Capacities of the pricing (type of pricing)
        """
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the pricing
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Duration for ordering the product
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def interval(self) -> builtins.int:
        """
        Interval of renewal
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="maximumQuantity")
    def maximum_quantity(self) -> builtins.int:
        """
        Maximum quantity that can be ordered
        """
        return pulumi.get(self, "maximum_quantity")

    @property
    @pulumi.getter(name="maximumRepeat")
    def maximum_repeat(self) -> builtins.int:
        """
        Maximum repeat for renewal
        """
        return pulumi.get(self, "maximum_repeat")

    @property
    @pulumi.getter(name="minimumQuantity")
    def minimum_quantity(self) -> builtins.int:
        """
        Minimum quantity that can be ordered
        """
        return pulumi.get(self, "minimum_quantity")

    @property
    @pulumi.getter(name="minimumRepeat")
    def minimum_repeat(self) -> builtins.int:
        """
        Minimum repeat for renewal
        """
        return pulumi.get(self, "minimum_repeat")

    @property
    @pulumi.getter(name="priceInUcents")
    def price_in_ucents(self) -> builtins.int:
        """
        Price of the product in micro-centims
        """
        return pulumi.get(self, "price_in_ucents")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetCartProductOptionsResultPricePriceResult']:
        """
        Price of the product (Price with its currency and textual representation)
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="pricingType")
    def pricing_type(self) -> builtins.str:
        """
        Pricing type
        """
        return pulumi.get(self, "pricing_type")


@pulumi.output_type
class GetCartProductOptionsResultPricePriceResult(dict):
    def __init__(__self__, *,
                 currency_code: builtins.str,
                 text: builtins.str,
                 value: builtins.float):
        """
        :param builtins.str currency_code: Currency code
        :param builtins.str text: Textual representation
        :param builtins.float value: The effective price
        """
        pulumi.set(__self__, "currency_code", currency_code)
        pulumi.set(__self__, "text", text)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="currencyCode")
    def currency_code(self) -> builtins.str:
        """
        Currency code
        """
        return pulumi.get(self, "currency_code")

    @property
    @pulumi.getter
    def text(self) -> builtins.str:
        """
        Textual representation
        """
        return pulumi.get(self, "text")

    @property
    @pulumi.getter
    def value(self) -> builtins.float:
        """
        The effective price
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetCartProductPlanPriceResult(dict):
    def __init__(__self__, *,
                 capacities: Sequence[Any],
                 description: builtins.str,
                 duration: builtins.str,
                 interval: builtins.int,
                 maximum_quantity: builtins.int,
                 maximum_repeat: builtins.int,
                 minimum_quantity: builtins.int,
                 minimum_repeat: builtins.int,
                 price_in_ucents: builtins.int,
                 prices: Sequence['outputs.GetCartProductPlanPricePriceResult'],
                 pricing_mode: builtins.str,
                 pricing_type: builtins.str):
        """
        :param Sequence[Any] capacities: Capacities of the pricing (type of pricing)
        :param builtins.str description: Description of the pricing
        :param builtins.str duration: Duration for ordering the product
        :param builtins.int interval: Interval of renewal
        :param builtins.int maximum_quantity: Maximum quantity that can be ordered
        :param builtins.int maximum_repeat: Maximum repeat for renewal
        :param builtins.int minimum_quantity: Minimum quantity that can be ordered
        :param builtins.int minimum_repeat: Minimum repeat for renewal
        :param builtins.int price_in_ucents: Price of the product in micro-centims
        :param Sequence['GetCartProductPlanPricePriceArgs'] prices: Price of the product (Price with its currency and textual representation)
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str pricing_type: Pricing type
        """
        pulumi.set(__self__, "capacities", capacities)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "interval", interval)
        pulumi.set(__self__, "maximum_quantity", maximum_quantity)
        pulumi.set(__self__, "maximum_repeat", maximum_repeat)
        pulumi.set(__self__, "minimum_quantity", minimum_quantity)
        pulumi.set(__self__, "minimum_repeat", minimum_repeat)
        pulumi.set(__self__, "price_in_ucents", price_in_ucents)
        pulumi.set(__self__, "prices", prices)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "pricing_type", pricing_type)

    @property
    @pulumi.getter
    def capacities(self) -> Sequence[Any]:
        """
        Capacities of the pricing (type of pricing)
        """
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the pricing
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Duration for ordering the product
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def interval(self) -> builtins.int:
        """
        Interval of renewal
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="maximumQuantity")
    def maximum_quantity(self) -> builtins.int:
        """
        Maximum quantity that can be ordered
        """
        return pulumi.get(self, "maximum_quantity")

    @property
    @pulumi.getter(name="maximumRepeat")
    def maximum_repeat(self) -> builtins.int:
        """
        Maximum repeat for renewal
        """
        return pulumi.get(self, "maximum_repeat")

    @property
    @pulumi.getter(name="minimumQuantity")
    def minimum_quantity(self) -> builtins.int:
        """
        Minimum quantity that can be ordered
        """
        return pulumi.get(self, "minimum_quantity")

    @property
    @pulumi.getter(name="minimumRepeat")
    def minimum_repeat(self) -> builtins.int:
        """
        Minimum repeat for renewal
        """
        return pulumi.get(self, "minimum_repeat")

    @property
    @pulumi.getter(name="priceInUcents")
    def price_in_ucents(self) -> builtins.int:
        """
        Price of the product in micro-centims
        """
        return pulumi.get(self, "price_in_ucents")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetCartProductPlanPricePriceResult']:
        """
        Price of the product (Price with its currency and textual representation)
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="pricingType")
    def pricing_type(self) -> builtins.str:
        """
        Pricing type
        """
        return pulumi.get(self, "pricing_type")


@pulumi.output_type
class GetCartProductPlanPricePriceResult(dict):
    def __init__(__self__, *,
                 currency_code: builtins.str,
                 text: builtins.str,
                 value: builtins.float):
        """
        :param builtins.str currency_code: Currency code
        :param builtins.str text: Textual representation
        :param builtins.float value: The effective price
        """
        pulumi.set(__self__, "currency_code", currency_code)
        pulumi.set(__self__, "text", text)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="currencyCode")
    def currency_code(self) -> builtins.str:
        """
        Currency code
        """
        return pulumi.get(self, "currency_code")

    @property
    @pulumi.getter
    def text(self) -> builtins.str:
        """
        Textual representation
        """
        return pulumi.get(self, "text")

    @property
    @pulumi.getter
    def value(self) -> builtins.float:
        """
        The effective price
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetCartProductPlanSelectedPriceResult(dict):
    def __init__(__self__, *,
                 capacities: Sequence[Any],
                 description: builtins.str,
                 duration: builtins.str,
                 interval: builtins.int,
                 maximum_quantity: builtins.int,
                 maximum_repeat: builtins.int,
                 minimum_quantity: builtins.int,
                 minimum_repeat: builtins.int,
                 price_in_ucents: builtins.int,
                 prices: Sequence['outputs.GetCartProductPlanSelectedPricePriceResult'],
                 pricing_mode: builtins.str,
                 pricing_type: builtins.str):
        """
        :param Sequence[Any] capacities: Capacities of the pricing (type of pricing)
        :param builtins.str description: Description of the pricing
        :param builtins.str duration: Duration for ordering the product
        :param builtins.int interval: Interval of renewal
        :param builtins.int maximum_quantity: Maximum quantity that can be ordered
        :param builtins.int maximum_repeat: Maximum repeat for renewal
        :param builtins.int minimum_quantity: Minimum quantity that can be ordered
        :param builtins.int minimum_repeat: Minimum repeat for renewal
        :param builtins.int price_in_ucents: Price of the product in micro-centims
        :param Sequence['GetCartProductPlanSelectedPricePriceArgs'] prices: Price of the product (Price with its currency and textual representation)
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str pricing_type: Pricing type
        """
        pulumi.set(__self__, "capacities", capacities)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "interval", interval)
        pulumi.set(__self__, "maximum_quantity", maximum_quantity)
        pulumi.set(__self__, "maximum_repeat", maximum_repeat)
        pulumi.set(__self__, "minimum_quantity", minimum_quantity)
        pulumi.set(__self__, "minimum_repeat", minimum_repeat)
        pulumi.set(__self__, "price_in_ucents", price_in_ucents)
        pulumi.set(__self__, "prices", prices)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "pricing_type", pricing_type)

    @property
    @pulumi.getter
    def capacities(self) -> Sequence[Any]:
        """
        Capacities of the pricing (type of pricing)
        """
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the pricing
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Duration for ordering the product
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def interval(self) -> builtins.int:
        """
        Interval of renewal
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="maximumQuantity")
    def maximum_quantity(self) -> builtins.int:
        """
        Maximum quantity that can be ordered
        """
        return pulumi.get(self, "maximum_quantity")

    @property
    @pulumi.getter(name="maximumRepeat")
    def maximum_repeat(self) -> builtins.int:
        """
        Maximum repeat for renewal
        """
        return pulumi.get(self, "maximum_repeat")

    @property
    @pulumi.getter(name="minimumQuantity")
    def minimum_quantity(self) -> builtins.int:
        """
        Minimum quantity that can be ordered
        """
        return pulumi.get(self, "minimum_quantity")

    @property
    @pulumi.getter(name="minimumRepeat")
    def minimum_repeat(self) -> builtins.int:
        """
        Minimum repeat for renewal
        """
        return pulumi.get(self, "minimum_repeat")

    @property
    @pulumi.getter(name="priceInUcents")
    def price_in_ucents(self) -> builtins.int:
        """
        Price of the product in micro-centims
        """
        return pulumi.get(self, "price_in_ucents")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetCartProductPlanSelectedPricePriceResult']:
        """
        Price of the product (Price with its currency and textual representation)
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="pricingType")
    def pricing_type(self) -> builtins.str:
        """
        Pricing type
        """
        return pulumi.get(self, "pricing_type")


@pulumi.output_type
class GetCartProductPlanSelectedPricePriceResult(dict):
    def __init__(__self__, *,
                 currency_code: builtins.str,
                 text: builtins.str,
                 value: builtins.float):
        """
        :param builtins.str currency_code: Currency code
        :param builtins.str text: Textual representation
        :param builtins.float value: The effective price
        """
        pulumi.set(__self__, "currency_code", currency_code)
        pulumi.set(__self__, "text", text)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="currencyCode")
    def currency_code(self) -> builtins.str:
        """
        Currency code
        """
        return pulumi.get(self, "currency_code")

    @property
    @pulumi.getter
    def text(self) -> builtins.str:
        """
        Textual representation
        """
        return pulumi.get(self, "text")

    @property
    @pulumi.getter
    def value(self) -> builtins.float:
        """
        The effective price
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetCartProductResultResult(dict):
    def __init__(__self__, *,
                 plan_code: builtins.str,
                 prices: Sequence['outputs.GetCartProductResultPriceResult'],
                 product_name: builtins.str,
                 product_type: builtins.str):
        """
        :param builtins.str plan_code: Product offer identifier
        :param Sequence['GetCartProductResultPriceArgs'] prices: Prices of the product offer
        :param builtins.str product_name: Name of the product
        :param builtins.str product_type: Product type
        """
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "prices", prices)
        pulumi.set(__self__, "product_name", product_name)
        pulumi.set(__self__, "product_type", product_type)

    @property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> builtins.str:
        """
        Product offer identifier
        """
        return pulumi.get(self, "plan_code")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetCartProductResultPriceResult']:
        """
        Prices of the product offer
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter(name="productName")
    def product_name(self) -> builtins.str:
        """
        Name of the product
        """
        return pulumi.get(self, "product_name")

    @property
    @pulumi.getter(name="productType")
    def product_type(self) -> builtins.str:
        """
        Product type
        """
        return pulumi.get(self, "product_type")


@pulumi.output_type
class GetCartProductResultPriceResult(dict):
    def __init__(__self__, *,
                 capacities: Sequence[Any],
                 description: builtins.str,
                 duration: builtins.str,
                 interval: builtins.int,
                 maximum_quantity: builtins.int,
                 maximum_repeat: builtins.int,
                 minimum_quantity: builtins.int,
                 minimum_repeat: builtins.int,
                 price_in_ucents: builtins.int,
                 prices: Sequence['outputs.GetCartProductResultPricePriceResult'],
                 pricing_mode: builtins.str,
                 pricing_type: builtins.str):
        """
        :param Sequence[Any] capacities: Capacities of the pricing (type of pricing)
        :param builtins.str description: Description of the pricing
        :param builtins.str duration: Duration for ordering the product
        :param builtins.int interval: Interval of renewal
        :param builtins.int maximum_quantity: Maximum quantity that can be ordered
        :param builtins.int maximum_repeat: Maximum repeat for renewal
        :param builtins.int minimum_quantity: Minimum quantity that can be ordered
        :param builtins.int minimum_repeat: Minimum repeat for renewal
        :param builtins.int price_in_ucents: Price of the product in micro-centims
        :param Sequence['GetCartProductResultPricePriceArgs'] prices: Price of the product (Price with its currency and textual representation)
        :param builtins.str pricing_mode: Pricing model identifier
        :param builtins.str pricing_type: Pricing type
        """
        pulumi.set(__self__, "capacities", capacities)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "interval", interval)
        pulumi.set(__self__, "maximum_quantity", maximum_quantity)
        pulumi.set(__self__, "maximum_repeat", maximum_repeat)
        pulumi.set(__self__, "minimum_quantity", minimum_quantity)
        pulumi.set(__self__, "minimum_repeat", minimum_repeat)
        pulumi.set(__self__, "price_in_ucents", price_in_ucents)
        pulumi.set(__self__, "prices", prices)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        pulumi.set(__self__, "pricing_type", pricing_type)

    @property
    @pulumi.getter
    def capacities(self) -> Sequence[Any]:
        """
        Capacities of the pricing (type of pricing)
        """
        return pulumi.get(self, "capacities")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description of the pricing
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def duration(self) -> builtins.str:
        """
        Duration for ordering the product
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter
    def interval(self) -> builtins.int:
        """
        Interval of renewal
        """
        return pulumi.get(self, "interval")

    @property
    @pulumi.getter(name="maximumQuantity")
    def maximum_quantity(self) -> builtins.int:
        """
        Maximum quantity that can be ordered
        """
        return pulumi.get(self, "maximum_quantity")

    @property
    @pulumi.getter(name="maximumRepeat")
    def maximum_repeat(self) -> builtins.int:
        """
        Maximum repeat for renewal
        """
        return pulumi.get(self, "maximum_repeat")

    @property
    @pulumi.getter(name="minimumQuantity")
    def minimum_quantity(self) -> builtins.int:
        """
        Minimum quantity that can be ordered
        """
        return pulumi.get(self, "minimum_quantity")

    @property
    @pulumi.getter(name="minimumRepeat")
    def minimum_repeat(self) -> builtins.int:
        """
        Minimum repeat for renewal
        """
        return pulumi.get(self, "minimum_repeat")

    @property
    @pulumi.getter(name="priceInUcents")
    def price_in_ucents(self) -> builtins.int:
        """
        Price of the product in micro-centims
        """
        return pulumi.get(self, "price_in_ucents")

    @property
    @pulumi.getter
    def prices(self) -> Sequence['outputs.GetCartProductResultPricePriceResult']:
        """
        Price of the product (Price with its currency and textual representation)
        """
        return pulumi.get(self, "prices")

    @property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> builtins.str:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @property
    @pulumi.getter(name="pricingType")
    def pricing_type(self) -> builtins.str:
        """
        Pricing type
        """
        return pulumi.get(self, "pricing_type")


@pulumi.output_type
class GetCartProductResultPricePriceResult(dict):
    def __init__(__self__, *,
                 currency_code: builtins.str,
                 text: builtins.str,
                 value: builtins.float):
        """
        :param builtins.str currency_code: Currency code
        :param builtins.str text: Textual representation
        :param builtins.float value: The effective price
        """
        pulumi.set(__self__, "currency_code", currency_code)
        pulumi.set(__self__, "text", text)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="currencyCode")
    def currency_code(self) -> builtins.str:
        """
        Currency code
        """
        return pulumi.get(self, "currency_code")

    @property
    @pulumi.getter
    def text(self) -> builtins.str:
        """
        Textual representation
        """
        return pulumi.get(self, "text")

    @property
    @pulumi.getter
    def value(self) -> builtins.float:
        """
        The effective price
        """
        return pulumi.get(self, "value")


